<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="content">
 *
 * @package Nutrilite Lite
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width">
<link rel="profile" href="https://gmpg.org/xfn/11">
<?php if(is_singular() && pings_open()) { ?>
<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' )); ?>">
<?php } ?>
<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php
	//wp_body_open hook from WordPress 5.2
	if ( function_exists( 'wp_body_open' ) ) {
	    wp_body_open();
	} else {
		do_action( 'wp_body_open' );
	}
?>
<a class="skip-link screen-reader-text" href="#sitemain">
	<?php _e( 'Skip to content', 'nutrilite-lite' ); ?>
</a>

<header id="header" class="main-header">
	<div class="wrapper">
		<div class="flex flex-stretch tab-block">
			
			<div class="left-area">
				<div class="site-title">
					<?php nutrilite_lite_the_custom_logo(); ?>
						<h1><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php esc_html(bloginfo( 'name' )); ?></a></h1>
						<?php $description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
						<p><?php echo esc_html($description); ?></p>
					<?php endif; ?>
				</div><!-- site title -->
			</div><!-- col-left -->
			<div class="right-area">
				<?php
					/* store values into variables */
					$hide_headinfo = get_theme_mod('disable_headinfo');

					$nutri_head_mail = esc_html(get_theme_mod('nutri_head_mail'));
					$nutri_head_phn = get_theme_mod('nutri_head_phn');
					$nutri_head_add = esc_html(get_theme_mod('nutri_head_add'));

					if( $hide_headinfo == '' ){
						echo '<div class="header-info">';
							if( $nutri_head_mail || $nutri_head_phn || $nutri_head_add != ''){ ?>
							<div class="flex">
								<?php if( $nutri_head_mail ) { ?>
								<div class="head-cell">
									<i class="fa fa-envelope-o" aria-hidden="true"></i>
									<div class="cell-text">
										<p><a href="mailto:<?php echo $nutri_head_mail; ?>"><?php echo $nutri_head_mail; ?></a></p>
									</div><!-- cell data -->
								</div><!-- cell -->
								<?php } if( $nutri_head_phn ) { ?>
								<div class="head-cell flex flex-center">
									<i class="fa fa-phone" aria-hidden="true"></i>
									<div class="cell-text">
										<p><a href="tel:<?php echo esc_attr($nutri_head_phn); ?>"><?php echo esc_html($nutri_head_phn); ?></a></p>
									</div><!-- cell data -->
								</div><!-- cell -->
								<?php } if( $nutri_head_add ) { ?>
								<div class="head-cell flex flex-center">
									<i class="fa fa-map-marker" aria-hidden="true"></i>
									<div class="cell-text last">
										<p><?php echo $nutri_head_add; ?></p>
									</div><!-- cell data -->
								</div><!-- cell -->
								<?php } if( get_theme_mod('nutri_cta_btn') || get_theme_mod('nutri_cta_btn_link') ) { ?>
								<div class="cta-button">
									<a href="<?php echo esc_url(get_theme_mod('nutri_cta_btn_link')); ?>"><span><?php echo esc_html(get_theme_mod('nutri_cta_btn')); ?></span></a>
								</div><!-- cta button -->
								<?php } ?>
							</div><!-- flex -->
							<?php } 
						echo '</div>'; 
					} ?>
				<div class="navigation">
					<div class="toggle">
						<a class="toggleMenu" href="#"><?php esc_html_e('Menu','nutrilite-lite'); ?></a>
					</div><!-- toggle -->
					<nav id="main-navigation" class="site-navigation primary-navigation sitenav" role="navigation">
						<?php wp_nav_menu( array('theme_location' => 'primary') ); ?>
					</nav>
				</div>
			</div><!-- right area-->
				
		</div><!-- align content -->
	</div><!-- wrapper -->
</header><!-- header -->